教父2 (豆瓣)
Description: 教父2电影简介和剧情介绍,教父2影评、图片、预告片、影讯、论坛、在线购票
Keywords: 教父2,The Godfather: Part II,教父2影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.58豆瓣电影Top250

# 教父2 The Godfather: Part II (1974)

导演: 弗朗西斯·福特·科波拉
编剧: 弗朗西斯·福特·科波拉 / 马里奥·普佐
主演: 阿尔·帕西诺 / 罗伯特·杜瓦尔 / 黛安·基顿 / 罗伯特·德尼罗 / 约翰·凯泽尔 / 塔莉娅·夏尔 / 李·斯特拉斯伯格 / 迈克尔·V·格佐 / G•D•斯普拉德林 / 理查德·布赖特 / 加斯通·莫辛 / 汤姆·罗斯奎 / 布鲁诺·柯比 / 弗兰克·西维罗 / 弗朗西丝卡·德·萨维奥 / 摩甘娜金 / 玛丽亚娜·希尔 / 莱奥波多·特里耶斯泰 / 多米尼克·查尼斯 / Amerigo Tot / 特洛伊·多纳胡 / 约翰·阿普雷亚 / 乔·斯皮内尔 / 阿贝·维高达 / 吉亚尼·罗素 / Maria Carta / 菲伊·斯潘 / 哈利·戴恩·斯坦通 / 卡明·卡里迪 / 丹尼·爱罗 / 威廉·鲍尔斯 / 约瑟夫·德拉·索尔特 / 卡门·阿尔根齐亚诺 / 乔·罗·格里普 / Ezio Flagello / 凯瑟琳·贝勒 / Saveria Mazzola / Tito Alba / 彼得·多纳特 / 汤姆·达尔格伦 / Phil Feldman / 罗杰·科曼 / 伊凡·科尔 / 艾丽卡·约恩 / Teresa Tirelli / 詹姆斯·肯恩 / Italia Coppola / 罗曼·科波拉 / 索菲亚·科波拉 / 朱莉·格雷格 / George Holmes / Buck Houghton / Shep Houghton / 小杉正一 / 加里·库尔茨 / Laura Lyons / 理查德·麦瑟森 / 约翰·梅根纳 / Harrison Ressler / Al Roberts / Hank Robinson / Filomena Spagnuolo
类型: 剧情 / 犯罪
制片国家/地区: 美国
语言: 英语 / 意大利语 / 西班牙语 / 拉丁语 / 西西里语
上映日期: 1974-12-12(纽约首映) / 1974-12-20(美国)
片长: 202分钟
又名: 教父续集(港) / 教父II
IMDb: tt0071562
豆瓣评分
引用
9.3
519496人评价
5星
68.4%
4星
26.7%
3星
4.5%
2星
0.3%
1星
0.1%
好于 99% 犯罪片
好于 99% 剧情片
想看 看过
评价:
推荐

## 教父2的剧情简介 · · · · · ·

迈克尔（阿尔·帕西诺 饰）是美利坚黑手党科利昂家族的头目。 迈克尔的父亲维托·安多里尼（罗伯特·德尼罗 饰）出生于意大利科利昂镇。1901年，维托的父亲安东尼奥、兄长保罗、母亲（玛丽亚·卡塔 饰）都死于黑手党西乔家族之手。9岁的维托只得漂洋过海逃亡美利坚谋生。入境时，海关官员（理查德·沃森 饰）将其名姓登记为维托·科利昂。 1958年，迈克尔为儿子安东尼（詹姆斯·古纳瑞斯 饰）举办了初领圣体的聚会，不想当晚便遭遇暗杀。迈克尔侥幸躲过一劫，两名杀手却被人灭口。 维托在异国他乡如何生存？他身负的血海深仇能否得报？想要迈克尔性命的是谁？将杀手灭口的又是谁？ ©豆瓣

## 教父2的演职员 · · · · · · ( 全部 68 )

- 弗朗西斯·福特·科波拉 导演
- 阿尔·帕西诺 饰 Michael
- 罗伯特·杜瓦尔 饰 Tom Hagen
- 黛安·基顿 饰 Kay
- 罗伯特·德尼罗 饰 Vito Corleone
- 约翰·凯泽尔 饰 Fredo Corleone

## 教父2的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1583 · 添加 )

## 教父2的获奖情况 · · · · · · ( 全部 )

- 第47届奥斯卡金像奖
- 最佳影片
- 弗雷德·鲁斯 / 弗朗西斯·福特·科波拉 / 加里·弗雷德里克森

- 第47届奥斯卡金像奖
- 最佳导演
- 弗朗西斯·福特·科波拉

- 第47届奥斯卡金像奖
- 最佳男主角(提名)
- 阿尔·帕西诺

## 喜欢这部电影的人也喜欢 · · · · · ·

  教父3

  美国往事

  猫鼠游戏

  低俗小说

  无间道

  爱尔兰人

  英雄本色

  上帝之城

  黑社会

  枪火

我要写短评

## 教父2的短评 · · · · · · ( 全部 64921 条 )

热门 / 最新 / 好友

### 1659 有用 17950 看过 2006-10-29 23:58:55

74/47th 第一部是关于神化的智慧。第二部是男人的光辉与悲哀，以及意大利的传统家族观念在美国的狗屁价值观前节节败退

### 1014 有用 有心打扰 看过 2011-11-21 23:49:43

即使敌人已经手无寸铁，但仍旧要处理掉。麦克深深的延续了父亲的性格。唯一不同的是家庭问题的处理，是时代变了，也是麦克与父亲之间的不同。两条主线相互交错，即使对比更是互补。阿尔·帕西诺最后的眼神，那是寂寞吗？

### 1552 有用 A-sun* 看过 2010-10-08 12:08:13

两代人的对比，Al Pacino和Robert Duvall都太帅了，不同的是，父亲拥有家庭与荣华，而Al Pacino几乎失去了所有亲人。

### 1335 有用 seeme | 北北 看过 2010-10-24 19:49:29

【720P】这部电影告诉我们，为什么“富不过三代”——因为富二代们的生活总是很混乱。

### 653 有用 薇羅尼卡 看过 2006-01-08 23:03:59

阿尔·帕西诺不能再帅，是年轻时的代表作。

> 更多短评 64921条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 教父2的影评 · · · · · · ( 全部 535 条 )

热门 / 最新 / 好友
东遇西 2007-06-12 11:03:58

## 回忆

在《教父》超过一亿美金的票房收入以及三个小金人奥斯卡金像奖在握的情况下，拍摄《教父Ⅱ》的科波拉拥有了他在拍摄《教父》时可望而不可及的优渥条件：充足的预算、充裕的时间以及足够的尊重和话语权。最明显的改变是，他已经由《教父》时朝不保夕的导演提升至现在的制片人之... (展开)
4772 114 254回应 收起
骑士猫 2010-06-17 13:07:17

## 转载 剧情解析

这篇影评可能有剧透

教父2的叙述线路有两条：一条是老V的，一条是麦克的，老V的线路可以理解为是麦克线路的辅线。他们之间似乎没有联系。但是，实际上是有有的。迫于教父2过于复杂的情节，我先将两条线路分开讲解，再细细说它们之间的联系。 很多人在看完教父2之后感到很乱，似乎没有开始就结束... (展开)
3570 76 274回应 收起
Norris 2006-08-05 00:42:46

## 两代教父的比较分析

在Godfather Trilogy的分析中，有一章叫作“Major Character Analysis”， 其中对两带教父做了一些比较。感觉这些比较当中有的有些表面化，所以以下就个人观点对Vito和Michael两代教父作一个比较。 我始终认为在Vito和Michael表面上所存在的不同绝对不能仅仅从两个人性格的差... (展开)
2826 104 282回应 收起
可可 2011-09-09 20:41:51

## 教父与弗雷多之死

这篇影评可能有剧透

我想很多人跟我一样，在最初看完《教父II》之后，对迈克.柯里昂一定要杀死他的哥哥弗雷多感到很不理解。尽管这个懦弱可悲的人物犯下了与他人私通的错误，差点害得迈克被乱枪扫射而死。可毕竟最初他对敌人的阴谋是不知情的，他也是被蒙在鼓里的（‘kept very much in the da... (展开)
1739 49 146回应 收起
随意 2009-09-06 12:00:12

## 引用 教父的经典台词

《教父》系列经典台词——一生受用 1.巨大财富的背后,都隐藏着罪恶。 2.让朋友低估你的优点，让敌人高估你的缺点。 3.不要憎恨你的敌人,那会影响你的判断力。 4.离你的朋友近些，但离你的敌人要更近，这样你才能更了解他。 5.这个世界本身就没有所谓的清白而言，你能坦... (展开)
401 19 28回应 收起
四分卫Alex 2007-06-08 16:38:24

## 灵魂孤独者 形象近乎于神

天才库布里克在工作室看了10遍教父,出来说'这可能是世上最伟大的电影'天才看了10遍才被征服,而如我这样的凡人只看一两遍就已经对其顶礼膜拜了. 我很为阿尔帕西诺遗憾,演了三集教父,没有拿到一座奥斯卡.白兰度在演完教父以后,有天晚上在个小饭馆吃饭,意大利黑手党的老大特意... (展开)
334 61 125回应 收起
迷开狼 2017-10-25 20:11:49

## 如果你是教父，是否处决亲哥？

这篇影评可能有剧透

在《教父2》中，第二代教父麦克与二哥弗雷多的兄弟恩怨是一条贯彻始终的主线。麦克与父亲的性格完全不同， 他是个理想主义者，不愿接受现实的价值观，但为了家族的生存不得不委曲求全，直到走向另一个极端。 因此片中的弗雷多虽然背叛了麦克，令其险些丧命，但观众仍然会同情前... (展开)
188 5 57回应 收起
馋老胚 2011-10-17 20:50:26

## （原创）看教父有感

老教父的父母兄弟都死于黑手党枪下，在他幼年穷途末路时，没有人敢向他的家庭伸出援助之手。按常理，这样的人对人性对社会应该有着刻骨的仇恨和鄙视。但他是个例外。这是他人性的光辉之处―――他是个有情有义，有社会责任感的黑手党老大。所以，他重视家庭，爱护妻儿，关照手... (展开)
175 30 40回应 收起
闫妮 2017-04-20 13:30:29

## 是男人传奇，也是家庭悲剧

Mike和Vito的区别之一大概在于对友人家人的态度。 Mike和人保持距离有一种生分感，对家人也投入感情精力不够多，更多是为了家族荣誉这种宏大的志向。可能他觉得是抓大放小吧，以为大家族事业繁荣家庭关系就会和睦，然而亲人一个个离他而去。如果说Vito更有一种大家长的味道，Mi... (展开)
78 6 5回应 收起
艾欧珀奇诺 2019-12-15 15:21:10

## 一夜风云散，变换了时空(《教父2》一万三千字终极解析)

这篇影评可能有剧透

《教父》大获成功，火爆全球之后，弗朗西斯科波拉再接再厉，于1974年推出了《教父2》，这部影片由教父2的原班人马主演，加入了由罗伯特德尼罗扮演的老教父。这部电影创造了续集电影的奇迹，获得了奥斯卡最佳影片，最佳导演，最佳男配角，最佳改编剧本四个重量级奖项，超越了教... (展开)
67 5回应 收起

> 更多影评 535篇

添加新讨论

## 讨论区 · · · · · ·

那个议员好像老布什 | 来自梦旅人 |  | 2022-11-21 22:23:13
凯为什么要堕胎？ | 来自风声 | 44 回应 | 2022-11-21 21:41:22
凯为什么会跟他闹翻？ | 来自Dolcevitaaa | 6 回应 | 2022-11-21 21:31:31
超人 | 来自Doki | 1 回应 | 2022-11-21 20:04:36
教父2里那些有意思的细节 | 来自旧少年 | 28 回应 | 2022-11-20 15:22:57

> 去这部影片的讨论区（全部204条）

## 关于《教父2》的问题 · · · · · · ( 全部26个 )

- 搞不懂最后麦克还是要除掉他哥哥？ 29人回答
- 影片里二代教父跑老头那说罗斯杀他,跑罗斯那说老头杀他,是怎么解读? 5人回答

> 全部26个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 今敏《造梦机器》剧组100部电影推荐 (恶魔的步调)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 奥斯卡最佳影片 (Boward)

## 谁在看这部电影 · · · · · ·

- sisiwaer
  1分钟前 看过
- 流俗
  4分钟前 看过
- brain
  11分钟前 想看

836241人看过 / 227586人想看

订阅教父2的评论:
feed: rss 2.0